// ConfigView.cpp - Implementation for the ConfigView class
// Provides controls for our screensaver


#include "ConfigView.h"


// Constructor
ConfigView::ConfigView(BRect frame, const char *name, int32* new_ticks)
 : BView(frame, name, 0, B_FOLLOW_ALL), ticks(new_ticks)
{
  // Variable init, etc.
  is_attached = false;
}
    
    
// AttachedToWindow() gets called when the view is attached to a parent
//  window, which is a good time to set up our menu widgets
void ConfigView::AttachedToWindow()
{
  // Note: we only want to do this once, to avoid leaking memory
  if(is_attached)
  {
    return;
  }

  // Make our background color match the one used by the screensaver
  //  configuration panel
  SetViewColor(ui_color(B_PANEL_BACKGROUND_COLOR));

  BFont font;  
  font_height f_height;

  float vert_spacing, y_pos;
  float s_width, s_height;


  // Create the configuration menu
  
  // First get some info about the font we're using
  this->GetFont(&font);
  this->GetFontHeight(&f_height);
  vert_spacing = f_height.ascent + f_height.descent + f_height.leading;
  y_pos = (vert_spacing*5);

  // Title  
  // Set starting row position
  title_view=new BStringView(BRect(0, y_pos, this->Bounds().Width(),
   vert_spacing + y_pos), B_EMPTY_STRING, CREDITS_TITLE);
  title_view->SetAlignment(B_ALIGN_CENTER);  
  this->AddChild(title_view);
  y_pos += vert_spacing;
    
  // Date / Version
  version_view=new BStringView(BRect(0, y_pos, this->Bounds().Width(),
   vert_spacing + y_pos), B_EMPTY_STRING, CREDITS_VERSION);
  version_view->SetAlignment(B_ALIGN_CENTER);  
  this->AddChild(version_view);
  y_pos += vert_spacing;
 
  // Credits
  credits_view=new BStringView(BRect(0, y_pos, this->Bounds().Width(),
   vert_spacing + y_pos), B_EMPTY_STRING, CREDITS_AUTHOR);
  credits_view->SetAlignment(B_ALIGN_CENTER);  
  this->AddChild(credits_view);
  y_pos += vert_spacing;
  
  // Spacing between credits and slider
  y_pos += vert_spacing + vert_spacing + vert_spacing;  
  
  // Slider for number of sparks
  ticks_slider = new BSlider(BRect(0, y_pos, this->Bounds().Width(),
   vert_spacing + y_pos), "const:slider1", "Iteration speed", new BMessage('tick'), MIN_TICKS, MAX_TICKS);
  ticks_slider->SetHashMarks(B_HASH_MARKS_BOTTOM);
  ticks_slider->SetHashMarkCount(10);
  ticks_slider->SetLimitLabels("Fast", "Slow");
  ticks_slider->SetPosition((float) *ticks/MAX_TICKS); 
  this->AddChild(ticks_slider);
  ticks_slider->SetTarget(this);
  ticks_slider->GetPreferredSize(&s_width, &s_height);
 

  // Make a note that we already setup everything here
  is_attached = true;
}


// Handle messages to sliderr, and update our configuration variables with
//  the current values of the sliderr
void ConfigView::MessageReceived(BMessage *msg)
{
  switch(msg->what)
  {
    case 'tick':
      *ticks = (int) (ticks_slider->Position() * MAX_TICKS);
      // Needed because of a slight rounding error
      if(*ticks < MIN_TICKS)
      {
        *ticks = MIN_TICKS;
      }
      if(*ticks > MAX_TICKS)
      {
        *ticks = MAX_TICKS;
      }
      break;
      
    default:
      break;
  }

  // Respond that we have handled the message that came in (whatever it was)
  //  so that it'll be removed from the message queue
  BView::MessageReceived(msg);
}


